define(
//begin v1.x content
({
	widgetLabel: "فحص هجاء دفعي",
	unfound: "غير موجودة",
	skip: "تخطي",
	skipAll: "تخطي كل",
	toDic: "اضافة الى القاموس",
	suggestions: "اقتراحات",
	replace: "استبدال",
	replaceWith: "استبدال مع",
	replaceAll: "استبدال كل",
	cancel: "الغاء",
	msg: "لا يوجد أخطاء في الهجاء",
	iSkip: "تخطي هذا",
	iSkipAll: "تخطي كل المماثل لهذا",
	iMsg: "لا توجد اقتراحات للهجاء"
})

//end v1.x content
);
